@@ -6,8 +6,7 @@ import sqlalchemy as sa
 from sqlalchemy.ext.declarative import declarative_base
 from tacview_client.config import DB_URL
 
-db_url = os.getenv("TACVIEW_DSN", DB_URL)
-engine = sa.create_engine(db_url)
+engine = sa.create_engine(DB_URL)
 metadata = sa.MetaData(engine)
 Base = declarative_base(engine, metadata)
 
